@@ -7,7 +7,7 @@ from feeluown.media import Quality, Media
 from feeluown.library import ModelType, SearchType
 from feeluown.utils.cache import cached_field
 from feeluown.utils.reader import create_reader, SequentialReader
-from .api import API
+from .api import API, CodeShouldBe200
 
 
 logger = logging.getLogger(__name__)
@@ -184,14 +184,14 @@ class NeteaseProvider(AbstractProvider, ProviderV2):
                 )
             else:
                 parent = None
-            comment = CommentModel(identifier=comment_data['commentId'],
+            comment = CommentModel(identifier=str(comment_data['commentId']),
                                    source=SOURCE,
                                    user=user,
                                    content=comment_data['content'],
                                    liked_count=comment_data['likedCount'],
                                    time=comment_data['time'] // 1000,
                                    parent=parent,
-                                   root_comment_id=comment_data['parentCommentId'])
+                                   root_comment_id=str(comment_data['parentCommentId']))
             hot_comments.append(comment)
         return hot_comments
 
@@ -368,6 +368,24 @@ class NeteaseProvider(AbstractProvider, ProviderV2):
         playlist = _deserialize(data, V2PlaylistSchema)
         return playlist
 
+    def playlist_delete(self, identifier):
+        try:
+            self.api.delete_playlist(identifier)
+        except CodeShouldBe200 as e:
+            logger.warning(f'delete playlist failed, {e}')
+            return False
+        return True
+
+    def playlist_create_by_name(self, name):
+        """
+        :raises NoUserLoggedIn:
+        :raises CodeShouldBe200: create playlist failed
+        """
+        user = self.get_current_user()
+        uid = user.identifier
+        data = self.api.new_playlist(uid, name)
+        return _deserialize(data, V2PlaylistSchema)
+
     def djradio_create_songs_rd(self, djradio_id):
         data = self.api.djradio_list(djradio_id, limit=1, offset=0)
         count = data.get('count', 0)
